pub enum CreateBatchInferenceJobError {
InvalidInput(String),
LimitExceeded(String),
ResourceAlreadyExists(String),
ResourceInUse(String),
ResourceNotFound(String),
}Expand description
Errors returned by CreateBatchInferenceJob
Variants
InvalidInput(String)
Provide a valid value for the field or parameter.
LimitExceeded(String)
The limit on the number of requests per second has been exceeded.
ResourceAlreadyExists(String)
The specified resource already exists.
ResourceInUse(String)
The specified resource is in use.
ResourceNotFound(String)
Could not find the specified resource.
Implementations