pub struct Algorithm {
pub algorithm_arn: Option<String>,
pub algorithm_image: Option<AlgorithmImage>,
pub creation_date_time: Option<f64>,
pub default_hyper_parameter_ranges: Option<DefaultHyperParameterRanges>,
pub default_hyper_parameters: Option<HashMap<String, String>>,
pub default_resource_config: Option<HashMap<String, String>>,
pub last_updated_date_time: Option<f64>,
pub name: Option<String>,
pub role_arn: Option<String>,
pub training_input_mode: Option<String>,
}Expand description
Describes a custom algorithm.
Fields
algorithm_arn: Option<String>The Amazon Resource Name (ARN) of the algorithm.
algorithm_image: Option<AlgorithmImage>The URI of the Docker container for the algorithm image.
creation_date_time: Option<f64>The date and time (in Unix time) that the algorithm was created.
default_hyper_parameter_ranges: Option<DefaultHyperParameterRanges>Specifies the default hyperparameters, their ranges, and whether they are tunable. A tunable hyperparameter can have its value determined during hyperparameter optimization (HPO).
default_hyper_parameters: Option<HashMap<String, String>>Specifies the default hyperparameters.
default_resource_config: Option<HashMap<String, String>>Specifies the default maximum number of training jobs and parallel training jobs.
last_updated_date_time: Option<f64>The date and time (in Unix time) that the algorithm was last updated.
name: Option<String>The name of the algorithm.
role_arn: Option<String>The Amazon Resource Name (ARN) of the role.
training_input_mode: Option<String>The training input mode.